@@ -50,8 +50,8 @@ sub sanitize_for_path {
     $str =~ s/^\s+|\s+\z//g;
     $str =~ s/\s/_/g             if $opt->{replace_spaces};
     $str =~ s/^\.+//             if $opt->{sanitize_filename};
-    $str =~ s{["/\\:*?<>&|]}{-}g if $opt->{sanitize_filename} == 1;
-    $str =~ s{/}{-}g             if $opt->{sanitize_filename} == 2;
+    $str =~ s{["/\\:*?<>&|]}{-}g if $opt->{sanitize_filename} == 1; # \0
+    $str =~ s{/}{-}g             if $opt->{sanitize_filename} == 2; # \0
     # NTFS unsupported characters:  / \ : " * ? < > |
     return $str;
 }
