@@ -50,10 +50,11 @@ sub uploader_history_menu {
             my ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{history} );
             my $prompt = 'Chosen:' . "\n";
             my @ids;
+            my $mark = '*';
 
             CHANNEL: while ( 1 ) {
                 my $confirm = '  CONFIRM';
-                my $hidden  = 'Your choice:';
+                my $hidden  = 'Your choice:' . $mark;
                 my @pre = ( $hidden, undef, $confirm );
                 my $choices = _available_uploader( \@pre, $sticky, $history, $removed_next );
                 # Choose
@@ -68,6 +69,7 @@ sub uploader_history_menu {
                         ( $sticky,  $sticky_url ) = _sticky_name_and_url( $opt->{sticky} );
                         ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{history} );
                         @ids = ();
+                        $mark = '*';
                         next CHANNEL;
                     }
                     else {
@@ -86,6 +88,7 @@ sub uploader_history_menu {
                         }
                         @$sticky_url = ();
                         @$sticky     = ();
+                        $mark = '';
                         next CHANNEL;
                     }
                     my $confirmed;
@@ -110,6 +113,7 @@ sub uploader_history_menu {
                         }
                         $count++;
                     }
+                    $mark = '*';
                     return @ids if $confirmed;
                 }
             }
