@@ -20,7 +20,7 @@ use App::YTDL::Helper  qw( check_mapping_stdout );
 
 sub _download_info {
     my ( $opt, $info, $ex, $video_id ) = @_;
-    return if $ex !~ /^(?:vimeo|youtube)\z/;
+    return if $info->{$ex}{$video_id}{fmt_to_info};
     my $webpage_url = $info->{$ex}{$video_id}{webpage_url};
     my $message     = "** GET download info: ";
     my $tmp = get_download_info( $opt, $webpage_url, $message );
