@@ -102,9 +102,9 @@ sub _menus {
             [ 'modify_timestamp',    "- File timestamp"      ],
         ],
         group_quality => [
-            [ 'auto_quality',     "- Auto quality mode"            ],
-            [ 'pref_qual_slots',  "- Slots 'preferred qualilties'" ],
-            [ '_print_pref_qual', "  Preferred qualities"          ],
+            [ 'auto_quality',     "- Set auto-quality mode"    ],
+            [ 'pref_qual_slots',  "- Number of slots"          ],
+            [ '_print_pref_qual', "  Preferred qualities" ],
         ],
         group_download => [
             [ 'useragent',            "- UserAgent"            ],
